@@ -80,7 +80,7 @@ static int CurrentConfigVersion = 1;
 static void migrateRenamedConfigKeys()
 {
     KSharedConfigPtr konsoleConfig = KSharedConfig::openConfig(QStringLiteral("konsolerc"));
-    KConfigGroup verGroup = konsoleConfig->group("General");
+    KConfigGroup verGroup = konsoleConfig->group(QStringLiteral("General"));
     const int savedVersion = verGroup.readEntry<int>("ConfigVersion", 0);
     if (savedVersion < CurrentConfigVersion) {
         struct KeyInfo {
@@ -93,7 +93,7 @@ static void migrateRenamedConfigKeys()
 
         // Migrate renamed config keys
         for (const auto &[group, oldName, newName] : keys) {
-            KConfigGroup cg = konsoleConfig->group(group);
+            KConfigGroup cg = konsoleConfig->group(QLatin1String(group));
             if (cg.exists() && cg.hasKey(oldName)) {
                 const bool value = cg.readEntry(oldName, false);
                 cg.deleteEntry(oldName);
@@ -104,7 +104,7 @@ static void migrateRenamedConfigKeys()
         // With 5.93 KColorSchemeManager from KConfigWidgets, handles the loading
         // and saving of the widget color scheme, and uses "ColorScheme" as the
         // entry name, so clean-up here
-        KConfigGroup cg(konsoleConfig, "UiSettings");
+        KConfigGroup cg(konsoleConfig, QStringLiteral("UiSettings"));
         const QString schemeName = cg.readEntry("WindowColorScheme");
         cg.deleteEntry("WindowColorScheme");
         cg.writeEntry("ColorScheme", schemeName);
