@@ -333,6 +333,12 @@ bool EditProfileDialog::isProfileNameValid()
 
     nameLenMax -= QStringLiteral(".profile").size();
 
+    // doesn't work on macOS and maybe other systems so make sure we have a sane value always
+    // See https://mail.kde.org/pipermail/kwrite-devel/2024-April/007139.html
+    if (nameLenMax < 0) {
+        nameLenMax = 100;
+    }
+
     if (_tempProfile->name().size() > nameLenMax) {
         setMessageGeneralPage(i18nc("@info", "Profile name exceeded maximum allowed length (%1).", nameLenMax));
         // Revert the name in the dialog
@@ -858,6 +864,10 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     _appearanceUi->useFontLineCharactersButton->setChecked(profile->useFontLineCharacters());
     connect(_appearanceUi->useFontLineCharactersButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::useFontLineCharacters);
 
+    _appearanceUi->useFontBrailleCharactersButton->setEnabled(!profile->property<bool>(Profile::UseFontLineCharacters));
+    _appearanceUi->useFontBrailleCharactersButton->setChecked(profile->property<bool>(Profile::UseFontBrailleCharacters));
+    connect(_appearanceUi->useFontBrailleCharactersButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::useFontBrailleCharacters);
+
     _mouseUi->enableMouseWheelZoomButton->setChecked(profile->mouseWheelZoomEnabled());
     connect(_mouseUi->enableMouseWheelZoomButton, &QCheckBox::toggled, this, &Konsole::EditProfileDialog::toggleMouseWheelZoom);
 
@@ -934,7 +944,7 @@ void EditProfileDialog::setupAppearancePage(const Profile::Ptr &profile)
     auto *getNewButton = new KNSWidgets::Button(this);
     connect(getNewButton, &KNSWidgets::Button::dialogFinished, this, &Konsole::EditProfileDialog::gotNewColorSchemes);
 
-    getNewButton->setText(QStringLiteral("Get New..."));
+    getNewButton->setText(i18n("Get New..."));
     getNewButton->setConfigFile(QStringLiteral("konsole.knsrc"));
     _appearanceUi->colorSchemesBtnLayout->addWidget(getNewButton);
 
@@ -1004,10 +1014,17 @@ void EditProfileDialog::setBoldIntense(bool enable)
 
 void EditProfileDialog::useFontLineCharacters(bool enable)
 {
+    _appearanceUi->useFontBrailleCharactersButton->setEnabled(!enable);
     preview(Profile::UseFontLineCharacters, enable);
     updateTempProfileProperty(Profile::UseFontLineCharacters, enable);
 }
 
+void EditProfileDialog::useFontBrailleCharacters(bool enable)
+{
+    preview(Profile::UseFontBrailleCharacters, enable);
+    updateTempProfileProperty(Profile::UseFontBrailleCharacters, enable);
+}
+
 void EditProfileDialog::toggleBlinkingCursor(bool enable)
 {
     preview(Profile::BlinkingCursorEnabled, enable);
@@ -1829,7 +1846,7 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr &profile)
 void EditProfileDialog::setTextEditorCombo(const Profile::Ptr &profile)
 {
     static const Enum::TextEditorCmd editorsList[] =
-        {Enum::Kate, Enum::KWrite, Enum::KDevelop, Enum::QtCreator, Enum::Gedit, Enum::gVim, Enum::CustomTextEditor};
+        {Enum::Kate, Enum::KWrite, Enum::KDevelop, Enum::QtCreator, Enum::Gedit, Enum::gVim, Enum::CustomTextEditor, Enum::Default};
 
     auto *editorCombo = _mouseUi->textEditorCombo;
 
@@ -1875,6 +1892,9 @@ void EditProfileDialog::setTextEditorCombo(const Profile::Ptr &profile)
             displayName = QStringLiteral("Custom");
             icon = QIcon::fromTheme(QStringLiteral("system-run"));
             break;
+        case Enum::Default:
+            displayName = i18n("Default for file type");
+            icon = QIcon::fromTheme(QStringLiteral("preferences-desktop-default-applications"));
         default:
             break;
         }
@@ -1882,7 +1902,7 @@ void EditProfileDialog::setTextEditorCombo(const Profile::Ptr &profile)
         editorCombo->addItem(icon, displayName);
 
         // For "CustomTextEditor" we don't check if the binary exists
-        const bool isAvailable = editor == Enum::CustomTextEditor || !QStandardPaths::findExecutable(exec).isEmpty();
+        const bool isAvailable = editor == Enum::CustomTextEditor || editor == Enum::Default || !QStandardPaths::findExecutable(exec).isEmpty();
         // Make un-available editors look disabled in the combobox
         model->item(static_cast<int>(editor))->setEnabled(isAvailable);
     }
@@ -1967,6 +1987,19 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
 
     _advancedUi->peekPrimaryWidget->setKeySequence(profile->peekPrimaryKeySequence());
     connect(_advancedUi->peekPrimaryWidget, &QKeySequenceEdit::editingFinished, this, &EditProfileDialog::peekPrimaryKeySequenceChanged);
+
+    const ButtonGroupOptions lineNums = {
+        _advancedUi->lineNums, // group
+        Profile::LineNumbers, // profileProperty
+        false, // preview
+        {
+            // buttons
+            {_advancedUi->lineNumsNever, Enum::HintsNever},
+            {_advancedUi->lineNumsURL, Enum::HintsURL},
+            {_advancedUi->lineNumsAlways, Enum::HintsAlways},
+        },
+    };
+    setupButtonGroup(lineNums, profile);
 }
 
 int EditProfileDialog::maxSpinBoxWidth(const KPluralHandlingSpinBox *spinBox, const KLocalizedString &suffix)
